from setuptools import setup


setup(name='Arni_distributions',
      version='1.2',
      description='Gaussian and Binomial distributions',
      packages=['Arni_distributions'],
      author="Arni khede",
      author_email="arnikhede03@gmail.com",
      zip_safe=False)